@@ -5,7 +5,8 @@ from dateutil.relativedelta import relativedelta
 
 from sql import Column
 
-from trytond.model import ModelView, ModelSQL, fields, sequence_ordered
+from trytond.model import (
+    ModelView, ModelSQL, DeactivableMixin, fields, sequence_ordered)
 from trytond import backend
 from trytond.pyson import Eval
 from trytond.transaction import Transaction
@@ -17,11 +18,10 @@ __all__ = ['PaymentTerm', 'PaymentTermLine', 'PaymentTermLineRelativeDelta',
     'TestPaymentTerm', 'TestPaymentTermView', 'TestPaymentTermViewResult']
 
 
-class PaymentTerm(ModelSQL, ModelView):
+class PaymentTerm(DeactivableMixin, ModelSQL, ModelView):
     'Payment Term'
     __name__ = 'account.invoice.payment_term'
     name = fields.Char('Name', size=None, required=True, translate=True)
-    active = fields.Boolean('Active')
     description = fields.Text('Description', translate=True)
     lines = fields.One2Many('account.invoice.payment_term.line', 'payment',
             'Lines')
@@ -49,10 +49,6 @@ class PaymentTerm(ModelSQL, ModelView):
         if not self.lines or not self.lines[-1].type == 'remainder':
             self.raise_user_error('last_remainder', self.rec_name)
 
-    @staticmethod
-    def default_active():
-        return True
-
     def compute(self, amount, currency, date=None):
         """Calculate payment terms and return a list of tuples
         with (date, amount) for each payment term line.
@@ -144,36 +140,10 @@ class PaymentTermLine(sequence_ordered(), ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
-        TableHandler = backend.get('TableHandler')
         sql_table = cls.__table__()
         super(PaymentTermLine, cls).__register__(module_name)
         cursor = Transaction().connection.cursor()
-        table = TableHandler(cls, module_name)
-
-        # Migration from 1.0 percent change into percentage
-        if table.column_exist('percent'):
-            cursor.execute(*sql_table.update(
-                    columns=[sql_table.percentage],
-                    values=[sql_table.percent * 100]))
-            table.drop_column('percent', exception=True)
-
-        # Migration from 2.2
-        if table.column_exist('delay'):
-            cursor.execute(*sql_table.update(
-                    columns=[sql_table.day],
-                    values=[31],
-                    where=sql_table.delay == 'end_month'))
-            table.drop_column('delay', exception=True)
-            lines = cls.search([])
-            for line in lines:
-                if line.percentage:
-                    cls.write([line], {
-                            'divisor': cls.round(Decimal('100.0') /
-                                line.percentage, cls.divisor.digits[1]),
-                            })
-
-        # Migration from 2.4: drop required on sequence
-        table.not_null_action('sequence', action='remove')
+        table = cls.__table_handler__(module_name)
 
         # Migration from 3.8: rename percentage into ratio
         if table.column_exist('percentage'):
@@ -345,7 +315,7 @@ class PaymentTermLineRelativeDelta(sequence_ordered(), ModelSQL, ModelView):
 
         super(PaymentTermLineRelativeDelta, cls).__register__(module_name)
 
-        line_table = TableHandler(Line, module_name)
+        line_table = Line.__table_handler__(module_name)
 
         # Migration from 3.4
         fields = ['day', 'month', 'weekday', 'months', 'weeks', 'days']
@@ -357,7 +327,7 @@ class PaymentTermLineRelativeDelta(sequence_ordered(), ModelSQL, ModelView):
                     + [Column(sql_table, f) for f in fields],
                     values=line.select(*columns)))
             for field in fields:
-                line_table.drop_column(field, exception=True)
+                line_table.drop_column(field)
 
     @staticmethod
     def default_months():
